@@ -33,6 +33,14 @@ _LOGGER = logging.getLogger(__name__)
 
 ApiType = TypeVar("ApiType", bound="EcoNetApiInterface")
 
+def _create_ssl_context() -> ssl.SSLContext:
+    """Create a SSL context for the MQTT connection."""
+    context = ssl.SSLContext(ssl.PROTOCOL_TLS)
+    context.load_default_certs()
+    return context
+
+_SSL_CONTEXT = _create_ssl_context()
+
 
 class EcoNetApiInterface:
     """
@@ -97,14 +105,10 @@ class EcoNetApiInterface:
             self._user_token, password=CLEAR_BLADE_SYSTEM_KEY
         )
         self._mqtt_client.enable_logger()
-        self._mqtt_client.tls_set(
-            ca_certs=None,
-            certfile=None,
-            keyfile=None,
-            cert_reqs=ssl.CERT_REQUIRED,
-            tls_version=ssl.PROTOCOL_TLS,
-            ciphers=None,
-        )
+
+        self._mqtt_client.tls_set_context(_SSL_CONTEXT)
+        self._mqtt_client.tls_insecure_set(False)
+
         self._mqtt_client.on_connect = self._on_connect
         self._mqtt_client.on_message = self._on_message
         self._mqtt_client.on_disconnect = self._on_disconnect
@@ -162,10 +166,10 @@ class EcoNetApiInterface:
         for _location in _locations:
             # They spelled it wrong...
             for _equip in _location.get("equiptments"):
-                _equip_obj: Equipment = None
-                equipment = self._equipment.get(_equip.get("device_name", ""), None)
+                serial = _equip.get("serial_number")
+                equipment = self._equipment.get(serial)
                 if equipment:
-                    equipment._update_equipment_info(_equip)
+                    equipment.update_equipment_info(_equip)
 
     async def get_equipment_by_type(self, equipment_type: List) -> Dict:
         """Get a list of equipment by the equipment EquipmentType"""
@@ -182,11 +186,12 @@ class EcoNetApiInterface:
     async def _get_location(self) -> List[Dict]:
         _headers = HEADERS.copy()
         _headers["ClearBlade-UserToken"] = self._user_token
+        payload = {"location_only": False, "type": "com.econet.econetconsumerandroid", "version": "6.0.0-375-01b4870e"}
 
         _session = ClientSession()
         try:
             async with _session.post(
-                f"{REST_URL}/code/{CLEAR_BLADE_SYSTEM_KEY}/getLocation", headers=_headers
+                f"{REST_URL}/code/{CLEAR_BLADE_SYSTEM_KEY}/getUserDataForApp", json=payload, headers=_headers
             ) as resp:
                 if resp.status == 200:
                     _json = await resp.json()
